#[repr(u8)]pub enum Csctrl2Tci {
STOP = 0,
RELOAD = 1,
}Variants
STOP = 0
Stop counter upon receiving a second trigger event while still counting from the first trigger event.
RELOAD = 1
Reload the counter upon receiving a second trigger event while still counting from the first trigger event.
Implementations
Sourceimpl Csctrl2Tci
impl Csctrl2Tci