#[repr(u8)]pub enum Csctrl3Cl1 {
NEVER = 0,
COMP1 = 1,
COMP2 = 2,
_RESERVED_3 = 3,
}Variants
NEVER = 0
Never preload
COMP1 = 1
Load upon successful compare with the value in COMP1
COMP2 = 2
Load upon successful compare with the value in COMP2
_RESERVED_3 = 3
Implementations
Sourceimpl Csctrl3Cl1
impl Csctrl3Cl1