#[repr(u8)]pub enum Sctrl3Oen {
INPUT = 0,
OFLAG_OUT = 1,
}Variants
INPUT = 0
The external pin is configured as an input.
OFLAG_OUT = 1
The OFLAG output signal is driven on the external pin. Other timer groups using this external pin as their input see the driven value. The polarity of the signal is determined by OPS.
Implementations